/*
 * Squawk messenger.
 * Copyright (C) 2019  Yury Gubich <blue@macaw.me>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#pragma once

#include <list>

#include <QWidget>
#include <QScopedPointer>
#include <QMenu>

#include "ui/models/info/omemo/keys.h"
#include "keydelegate.h"
#include "shared/icons.h"
#include "shared/keyinfo.h"

namespace UI {
namespace Ui {
class Omemo;
}

class Omemo : public QWidget {
    Q_OBJECT
public:
    Omemo(QWidget* parent = nullptr);
    ~Omemo();

    void setData(const std::list<Shared::KeyInfo>& keys);
    const QString title() const;

private slots:
    void onActiveKeysContextMenu(const QPoint& pos);

private:
    void generateMockData();
    void unusedVisibility(bool visible);
    void deviceKeyVisibility(bool visible);

private:
    QScopedPointer<Ui::Omemo> m_ui;
    UI::KeyDelegate deviceKeyDelegate;
    UI::KeyDelegate keysDelegate;
    UI::KeyDelegate unusedKeysDelegate;
    Models::Keys deviceKeyModel;
    Models::Keys keysModel;
    Models::Keys unusedKeysModel;
    QMenu* contextMenu;
};
}
